Serializer

Struct Serializer 

pub struct Serializer<W> { /* private fields */ }
A structure for serializing Rust values into Smile.

Implementations

Source

impl Serializer<()>

pub fn builder() -> Builder

Returns a builder used to configure a Serializer.

Source

impl<W> Serializer<W>
where W: Write,

pub fn new(writer: W) -> Self

Creates a new Serializer with default settings.

pub fn write_header(&mut self) -> Result<(), Error>

Writes the Smile header to the writer, if not already written.

This will happen automatically when the first value is serialized, but this method can be used to explicitly write it if desired.

pub fn end(&mut self) -> Result<(), Error>

Writes the Smile end of stream token to the writer.

The end of stream indicator is not required in a Smile encoding, but can help with framing in some contexts.

This should only be called after serializing all data.

pub fn get_ref(&self) -> &W

Returns a shared reference to the inner writer.

pub fn get_mut(&mut self) -> &mut W

Returns a mutable reference to the inner writer.

pub fn into_inner(self) -> W

Consumes the Serializer, returning the inner writer.