pub struct Serializer<W> { /* private fields */ }Expand description
A structure for serializing Rust values into Smile.
Implementations
Sourceimpl Serializer<()>
impl Serializer<()>
Sourceimpl<W> Serializer<W>where
W: Write,
impl<W> Serializer<W>where
W: Write,
Sourcepub fn write_header(&mut self) -> Result<(), Error>
pub fn write_header(&mut self) -> Result<(), Error>
Writes the Smile header to the writer, if not already written.
This will happen automatically when the first value is serialized, but this method can be used to explicitly write it if desired.
Sourcepub fn end(&mut self) -> Result<(), Error>
pub fn end(&mut self) -> Result<(), Error>
Writes the Smile end of stream token to the writer.
The end of stream indicator is not required in a Smile encoding, but can help with framing in some contexts.
This should only be called after serializing all data.
Sourcepub fn into_inner(self) -> W
pub fn into_inner(self) -> W
Consumes the Serializer, returning the inner writer.